"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLintCommand = void 0;
function createLintCommand(deps) {
    const { linter, git, logger } = deps;
    return {
        execute() {
            return __awaiter(this, void 0, void 0, function* () {
                let timestamp = new Date().getTime();
                let allTypescriptFiles = yield git.findAllTypescriptFiles();
                let results = yield Promise.all([
                    linter.lintOnce(false, allTypescriptFiles),
                ]);
                let toolErrors = results.filter((result) => result === false).length;
                logger.log("lint", `Lint task took ${Math.round((new Date().getTime() - timestamp) / 1000)} seconds`);
                if (toolErrors !== 0) {
                    logger.error("lint", `${toolErrors} tool${toolErrors === 1 ? "" : "s"} reported errors`);
                    return false;
                }
                return true;
            });
        },
    };
}
exports.createLintCommand = createLintCommand;
//# sourceMappingURL=lint.js.map